@@ -5,6 +5,7 @@ from heimdall_valid_bank.calculate_number_agency import CalculateAgency
 from heimdall_valid_bank.common_validate import CommonValidate
 from heimdall_valid_bank.generic_validators import GenericValidators
 
+
 class AgencyValidate(CommonValidate):
     """ 
         This class is responsible for validating the bank agency number
@@ -14,7 +15,7 @@ class AgencyValidate(CommonValidate):
             agency (string): Agency number with or without the digit ex.: 2345-9, 2345.
             digit_agency (String): Digit of the agency, if passed with the agency it is not necessary to inform the digit here.
     """
-    
+
     def __init__(self, **kwargs):
         self.bank_code = kwargs.get('bank_code')
         self.agency = kwargs.get('agency')
@@ -22,18 +23,9 @@ class AgencyValidate(CommonValidate):
 
     def start(self):
         try:
-            regex = re.match('^[0-9]{1,4}(-[0-9a-zA-Z]{1,2})?$', self.agency)
-            if regex is None:
-                raise InvalidAgencyNumber()
-            
-            if  len(self.agency) > 4:
-                agency = re.sub('[^A-Za-z0-9]+', '', self.agency)
-                self.agency = agency[0:4]
-                self.digit_agency = agency[4:len(agency)]
-            
             if self.bank_code not in GenericVariables.LIST_BANKS:
                 return self.valid_agency_generic()
-            
+
             switcher = {
                 '001': self.valid_agency_bb,
                 '237': self.valid_agency_bradesco,
@@ -53,8 +45,9 @@ class AgencyValidate(CommonValidate):
         """
           Valida agências genéricas
         """
+        self.__format_agency()
         result = GenericValidators.agency_is_valid(self.agency)
-        
+
         if self.digit_agency:
             result = GenericValidators.agency_digit_is_valid(self.digit_agency)
 
@@ -65,6 +58,7 @@ class AgencyValidate(CommonValidate):
            Valida a agência e o dígito verificador do banco do Brasil
            Tamanho da Agência - 4 Dígitos + 1 DV
         """
+        self.__format_agency(True)
         agency_is_valid = super().agency_is_valid(self.agency)
 
         if not agency_is_valid:
@@ -79,7 +73,7 @@ class AgencyValidate(CommonValidate):
 
         if not check_number_calculated_digit:
             raise InvalidAgencyNumber()
-      
+
         return check_number_calculated_digit == self.digit_agency.upper()
 
     def valid_agency_banrisul(self):
@@ -87,8 +81,9 @@ class AgencyValidate(CommonValidate):
           Valida a agência e dígito verificador do banco Banrisul
           Tamanho da Agência - 4 Dígitos
         """
+        self.__format_agency()
         result_agency_valid = super().agency_is_valid(self.agency)
-        
+
         if not result_agency_valid:
             raise InvalidAgencyNumber()
 
@@ -99,24 +94,26 @@ class AgencyValidate(CommonValidate):
             Valida a agência e o dígito verificador do banco Bradesco
             Tamanho da Agência - 4 Dígitos + 2 DV
         """
-        result_agency_valid = super().agency_is_valid(self.agency)
+        self.__format_agency(True)
         
+        result_agency_valid = super().agency_is_valid(self.agency)
+
         if not result_agency_valid:
             raise InvalidAgencyNumber()
-      
+
         result_digit_agency_valid = super().agency_digit_is_valid(self.digit_agency)
-       
+
         if not result_digit_agency_valid:
             raise InvalidDigitAgencyNumber()
 
         check_number_calculated_agency = CalculateAgency(self.agency).calculate_agency_bradesco()
         if not check_number_calculated_agency:
             raise InvalidAgencyNumber()
-        
+
         check_number_informed_digit = self.digit_agency.upper()
         if check_number_informed_digit == '0':
             return check_number_calculated_agency == check_number_informed_digit or check_number_calculated_agency == 'P'
-        
+
         return check_number_calculated_agency == check_number_informed_digit
 
     def valid_agency_citibank(self):
@@ -124,6 +121,7 @@ class AgencyValidate(CommonValidate):
           Valida a agência do banco Citibank
           Tamanho da Agência - 4 Dígitos - Não tem dígito verificador
         """
+        self.__format_agency()
         result_agency_valid = super().agency_is_valid(self.agency)
 
         if not result_agency_valid:
@@ -136,8 +134,9 @@ class AgencyValidate(CommonValidate):
           Valida a agência do banco Itaú
           Tamanho da Agência - 4 Dígitos - Não tem dígito verificador
         """
+        self.__format_agency()
         result_agency_valid = super().agency_is_valid(self.agency)
-        
+
         if not result_agency_valid:
             raise InvalidAgencyNumber()
 
@@ -148,6 +147,7 @@ class AgencyValidate(CommonValidate):
            Valida a agência do banco Santander
            Tamanho da Agência - 4 Dígitos - Não tem dígito verificador
         """
+        self.__format_agency()
         result_agency_valid = super().agency_is_valid(self.agency)
 
         if not result_agency_valid:
@@ -160,6 +160,7 @@ class AgencyValidate(CommonValidate):
            Valida a agência do banco Caixa Econômica Federal
            Tamanho da Agência - 4 Dígitos - Não tem dígito verificador
         """
+        self.__format_agency()
         result_agency_valid = super().agency_is_valid(self.agency)
 
         if not result_agency_valid:
@@ -172,9 +173,30 @@ class AgencyValidate(CommonValidate):
            Valida a agência do banco Nu Pagamentos (Nubank)
            Tamanho da Agência - 4 Dígitos - Não tem dígito verificador
         """
+        self.__format_agency()
         result_agency_valid = super().agency_is_valid(self.agency)
 
         if not result_agency_valid:
             raise InvalidAgencyNumber()
-        
+
         return True
+
+    def __format_agency(self, is_digit_agency=False):
+        """
+            Format the agency
+        """        
+        agency = re.sub('[^A-Za-z0-9]+', '', self.agency)
+        self.agency = agency
+        
+        if is_digit_agency and len(self.agency) > 4:
+            self.agency = agency[0:4]
+            self.digit_agency = agency[4:len(agency)]
+            return {}
+        
+        regex = re.match('^[0-9]{1,4}(-[0-9a-zA-Z]{1,2})?$', self.agency)
+        if regex is None:
+            raise InvalidAgencyNumber()
+
+        
+        
+        
\ No newline at end of file
